/* Do not edit.  Autogenerated from src/gthumb.h.template */

/*
 *  GThumb
 *
 *  Copyright (C) 2009 The Free Software Foundation, Inc.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
#ifndef GTHUMB_H
#define GTHUMB_H

#include <gthumb/gth-enum-types.h>
#include <gthumb/gth-marshal.h>
#include <gthumb/cairo-scale.h>
#include <gthumb/cairo-utils.h>
#include <gthumb/dom.h>
#include <gthumb/gedit-message-area.h>
#include <gthumb/gfixed.h>
#include <gthumb/gio-utils.h>
#include <gthumb/glib-utils.h>
#include <gthumb/gnome-desktop-thumbnail.h>
#include <gthumb/gsignature.h>
#include <gthumb/gth-auto-paned.h>
#include <gthumb/gth-async-task.h>
#include <gthumb/gth-buffer-data.h>
#include <gthumb/gth-browser.h>
#include <gthumb/gth-color-scale.h>
#include <gthumb/gth-dumb-notebook.h>
#include <gthumb/gth-duplicable.h>
#include <gthumb/gth-embedded-dialog.h>
#include <gthumb/gth-empty-list.h>
#include <gthumb/gth-extensions.h>
#include <gthumb/gth-file-chooser-dialog.h>
#include <gthumb/gth-error.h>
#include <gthumb/gth-file-data.h>
#include <gthumb/gth-file-list.h>
#include <gthumb/gth-file-properties.h>
#include <gthumb/gth-file-selection.h>
#include <gthumb/gth-file-source.h>
#include <gthumb/gth-file-source-vfs.h>
#include <gthumb/gth-file-store.h>
#include <gthumb/gth-file-tool.h>
#include <gthumb/gth-file-view.h>
#include <gthumb/gth-filter.h>
#include <gthumb/gth-filterbar.h>
#include <gthumb/gth-filter-editor-dialog.h>
#include <gthumb/gth-filter-file.h>
#include <gthumb/gth-folder-tree.h>
#include <gthumb/gth-grid-view.h>
#include <gthumb/gth-histogram.h>
#include <gthumb/gth-histogram-view.h>
#include <gthumb/gth-hook.h>
#include <gthumb/gth-icon-cache.h>
#include <gthumb/gth-image.h>
#include <gthumb/gth-image-dragger.h>
#include <gthumb/gth-image-history.h>
#include <gthumb/gth-image-list-task.h>
#include <gthumb/gth-image-loader.h>
#include <gthumb/gth-image-navigator.h>
#include <gthumb/gth-image-preloader.h>
#include <gthumb/gth-image-saver.h>
#include <gthumb/gth-image-selector.h>
#include <gthumb/gth-image-task.h>
#include <gthumb/gth-image-utils.h>
#include <gthumb/gth-image-viewer.h>
#include <gthumb/gth-image-viewer-tool.h>
#include <gthumb/gth-info-bar.h>
#include <gthumb/gth-load-file-data-task.h>
#include <gthumb/gth-location-chooser.h>
#include <gthumb/gth-main.h>
#include <gthumb/gth-menu-action.h>
#include <gthumb/gth-menu-button.h>
#include <gthumb/gth-metadata.h>
#include <gthumb/gth-metadata-chooser.h>
#include <gthumb/gth-metadata-provider.h>
#include <gthumb/gth-monitor.h>
#include <gthumb/gth-multipage.h>
#include <gthumb/gth-overwrite-dialog.h>
#include <gthumb/gth-paned.h>
#include <gthumb/gth-preferences.h>
#include <gthumb/gth-progress-dialog.h>
#include <gthumb/gth-request-dialog.h>
#include <gthumb/gth-save-file-data-task.h>
#include <gthumb/gth-save-image-task.h>
#include <gthumb/gth-screensaver.h>
#include <gthumb/gth-sidebar.h>
#include <gthumb/gth-statusbar.h>
#include <gthumb/gth-source-tree.h>
#include <gthumb/gth-stock.h>
#include <gthumb/gth-string-list.h>
#include <gthumb/gth-tags-entry.h>
#include <gthumb/gth-tags-file.h>
#include <gthumb/gth-task.h>
#include <gthumb/gth-test.h>
#include <gthumb/gth-test-category.h>
#include <gthumb/gth-test-chain.h>
#include <gthumb/gth-test-selector.h>
#include <gthumb/gth-test-simple.h>
#include <gthumb/gth-thumb-loader.h>
#include <gthumb/gth-time.h>
#include <gthumb/gth-time-selector.h>
#include <gthumb/gth-toggle-menu-action.h>
#include <gthumb/gth-toggle-menu-tool-button.h>
#include <gthumb/gth-toolbox.h>
#include <gthumb/gth-uri-list.h>
#include <gthumb/gth-user-dir.h>
#include <gthumb/gth-viewer-page.h>
#include <gthumb/gth-window.h>
#include <gthumb/gtk-utils.h>
#include <gthumb/gvaluehash.h>
#include <gthumb/main.h>
#include <gthumb/pixbuf-cache.h>
#include <gthumb/pixbuf-io.h>
#include <gthumb/pixbuf-utils.h>
#include <gthumb/typedefs.h>
#include <gthumb/zlib-utils.h>

#endif /* GTHUMB_H */
