
#ifndef __gth_marshal_MARSHAL_H__
#define __gth_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* BOOLEAN:ENUM,ENUM (/usr/src/ports/gthumb/gthumb-3.2.9.1-2.x86_64/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:1) */
extern void gth_marshal_BOOLEAN__ENUM_ENUM (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
                                            const GValue *param_values,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);

/* BOOLEAN:VOID (/usr/src/ports/gthumb/gthumb-3.2.9.1-2.x86_64/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:2) */
extern void gth_marshal_BOOLEAN__VOID (GClosure     *closure,
                                       GValue       *return_value,
                                       guint         n_param_values,
                                       const GValue *param_values,
                                       gpointer      invocation_hint,
                                       gpointer      marshal_data);

/* VOID:BOOLEAN,POINTER (/usr/src/ports/gthumb/gthumb-3.2.9.1-2.x86_64/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:3) */
extern void gth_marshal_VOID__BOOLEAN_POINTER (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
                                               const GValue *param_values,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);

/* VOID:BOXED,BOXED (/usr/src/ports/gthumb/gthumb-3.2.9.1-2.x86_64/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:4) */
extern void gth_marshal_VOID__BOXED_BOXED (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
                                           const GValue *param_values,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);

/* VOID:ENUM,ENUM (/usr/src/ports/gthumb/gthumb-3.2.9.1-2.x86_64/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:5) */
extern void gth_marshal_VOID__ENUM_ENUM (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
                                         const GValue *param_values,
                                         gpointer      invocation_hint,
                                         gpointer      marshal_data);

/* VOID:INT,INT (/usr/src/ports/gthumb/gthumb-3.2.9.1-2.x86_64/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:6) */
extern void gth_marshal_VOID__INT_INT (GClosure     *closure,
                                       GValue       *return_value,
                                       guint         n_param_values,
                                       const GValue *param_values,
                                       gpointer      invocation_hint,
                                       gpointer      marshal_data);

/* VOID:OBJECT,BOOLEAN (/usr/src/ports/gthumb/gthumb-3.2.9.1-2.x86_64/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:7) */
extern void gth_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);

/* VOID:OBJECT,BOXED,ENUM (/usr/src/ports/gthumb/gthumb-3.2.9.1-2.x86_64/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:8) */
extern void gth_marshal_VOID__OBJECT_BOXED_ENUM (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
                                                 const GValue *param_values,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);

/* VOID:OBJECT,BOXED,INT,ENUM (/usr/src/ports/gthumb/gthumb-3.2.9.1-2.x86_64/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:9) */
extern void gth_marshal_VOID__OBJECT_BOXED_INT_ENUM (GClosure     *closure,
                                                     GValue       *return_value,
                                                     guint         n_param_values,
                                                     const GValue *param_values,
                                                     gpointer      invocation_hint,
                                                     gpointer      marshal_data);

/* VOID:OBJECT,OBJECT (/usr/src/ports/gthumb/gthumb-3.2.9.1-2.x86_64/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:10) */
extern void gth_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);

/* VOID:OBJECT,OBJECT,INT,INT,POINTER (/usr/src/ports/gthumb/gthumb-3.2.9.1-2.x86_64/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:11) */
extern void gth_marshal_VOID__OBJECT_OBJECT_INT_INT_POINTER (GClosure     *closure,
                                                             GValue       *return_value,
                                                             guint         n_param_values,
                                                             const GValue *param_values,
                                                             gpointer      invocation_hint,
                                                             gpointer      marshal_data);

/* VOID:OBJECT,POINTER (/usr/src/ports/gthumb/gthumb-3.2.9.1-2.x86_64/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:12) */
extern void gth_marshal_VOID__OBJECT_POINTER (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);

/* VOID:OBJECT,STRING (/usr/src/ports/gthumb/gthumb-3.2.9.1-2.x86_64/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:13) */
extern void gth_marshal_VOID__OBJECT_STRING (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);

/* VOID:OBJECT,UINT (/usr/src/ports/gthumb/gthumb-3.2.9.1-2.x86_64/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:14) */
extern void gth_marshal_VOID__OBJECT_UINT (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
                                           const GValue *param_values,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);

/* VOID:POINTER,POINTER (/usr/src/ports/gthumb/gthumb-3.2.9.1-2.x86_64/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:15) */
extern void gth_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
                                               const GValue *param_values,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);

/* VOID:STRING,STRING,BOOLEAN,DOUBLE (/usr/src/ports/gthumb/gthumb-3.2.9.1-2.x86_64/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:16) */
extern void gth_marshal_VOID__STRING_STRING_BOOLEAN_DOUBLE (GClosure     *closure,
                                                            GValue       *return_value,
                                                            guint         n_param_values,
                                                            const GValue *param_values,
                                                            gpointer      invocation_hint,
                                                            gpointer      marshal_data);

G_END_DECLS

#endif /* __gth_marshal_MARSHAL_H__ */

